Class: NutanixClustermgmt::ClustermgmtV40ConfigClusterNetwork

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb

Overview

Network details of a cluster.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigClusterNetwork

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigClusterNetwork` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigClusterNetwork`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'external_address')
    self.external_address = attributes[:'external_address']
  end

  if attributes.key?(:'name_servers')
    if (value = attributes[:'name_servers']).is_a?(Array)
      self.name_servers = value
    end
  end

  if attributes.key?(:'ntp_servers')
    if (value = attributes[:'ntp_servers']).is_a?(Array)
      self.ntp_servers = value
    end
  end

  if attributes.key?(:'fqdn')
    self.fqdn = attributes[:'fqdn']
  end
end

Instance Attribute Details

#external_addressObject

Returns the value of attribute external_address.



19
20
21
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 19

def external_address
  @external_address
end

#fqdnObject

Cluster fully qualified domain name. This is part of payload for cluster update operation only.



28
29
30
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 28

def fqdn
  @fqdn
end

#name_serversObject

List of name servers on a cluster. This is part of payload for both cluster create & update operations. For create operation, only ipv4 address / fqdn values are supported currently.



22
23
24
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 22

def name_servers
  @name_servers
end

#ntp_serversObject

List of NTP servers on a cluster. This is part of payload for both cluster create & update operations. For create operation, only ipv4 address / fqdn values are supported currently.



25
26
27
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 25

def ntp_servers
  @ntp_servers
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 31

def self.attribute_map
  {
    :'external_address' => :'externalAddress',
    :'name_servers' => :'nameServers',
    :'ntp_servers' => :'ntpServers',
    :'fqdn' => :'fqdn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 51

def self.openapi_types
  {
    :'external_address' => :'CommonV10ConfigIPAddress',
    :'name_servers' => :'Array<CommonV10ConfigIPAddressOrFQDN>',
    :'ntp_servers' => :'Array<CommonV10ConfigIPAddressOrFQDN>',
    :'fqdn' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



197
198
199
200
201
202
203
204
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 197

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      external_address == o.external_address &&
      name_servers == o.name_servers &&
      ntp_servers == o.ntp_servers &&
      fqdn == o.fqdn
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 214

def hash
  [external_address, name_servers, ntp_servers, fqdn].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name_servers.nil? && @name_servers.length > 1024
    invalid_properties.push('invalid value for "name_servers", number of items must be less than or equal to 1024.')
  end

  if !@name_servers.nil? && @name_servers.length < 0
    invalid_properties.push('invalid value for "name_servers", number of items must be greater than or equal to 0.')
  end

  if !@ntp_servers.nil? && @ntp_servers.length > 1024
    invalid_properties.push('invalid value for "ntp_servers", number of items must be less than or equal to 1024.')
  end

  if !@ntp_servers.nil? && @ntp_servers.length < 0
    invalid_properties.push('invalid value for "ntp_servers", number of items must be greater than or equal to 0.')
  end

  pattern = Regexp.new(/^([a-z0-9]+(-[a-z0-9]+)*\.)+([a-z0-9]+(-[a-z0-9]+)*){1,63}$/)
  if !@fqdn.nil? && @fqdn !~ pattern
    invalid_properties.push("invalid value for \"fqdn\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
139
140
141
142
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_cluster_network.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name_servers.nil? && @name_servers.length > 1024
  return false if !@name_servers.nil? && @name_servers.length < 0
  return false if !@ntp_servers.nil? && @ntp_servers.length > 1024
  return false if !@ntp_servers.nil? && @ntp_servers.length < 0
  return false if !@fqdn.nil? && @fqdn !~ Regexp.new(/^([a-z0-9]+(-[a-z0-9]+)*\.)+([a-z0-9]+(-[a-z0-9]+)*){1,63}$/)
  true
end