Class: NutanixClustermgmt::ClustermgmtV40ConfigComputeNodeItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixClustermgmt::ClustermgmtV40ConfigComputeNodeItem
- Defined in:
- lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb
Overview
Compute node details.
Instance Attribute Summary collapse
-
#block_id ⇒ Object
Rackable unit Id in which node resides.
-
#digital_certificate_map_list ⇒ Object
List of objects containing digital_certificate_base64 and key_management_server_uuid fields for key management server.
-
#hypervisor_hostname ⇒ Object
Name of the host.
-
#hypervisor_ip ⇒ Object
Returns the value of attribute hypervisor_ip.
-
#ipmi_ip ⇒ Object
Returns the value of attribute ipmi_ip.
-
#model ⇒ Object
Rackable unit model type.
-
#node_position ⇒ Object
Position of a node in a rackable unit.
-
#node_uuid ⇒ Object
UUID of the host.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigComputeNodeItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigComputeNodeItem
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigComputeNodeItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigComputeNodeItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'node_uuid') self.node_uuid = attributes[:'node_uuid'] end if attributes.key?(:'block_id') self.block_id = attributes[:'block_id'] end if attributes.key?(:'node_position') self.node_position = attributes[:'node_position'] end if attributes.key?(:'hypervisor_ip') self.hypervisor_ip = attributes[:'hypervisor_ip'] end if attributes.key?(:'ipmi_ip') self.ipmi_ip = attributes[:'ipmi_ip'] end if attributes.key?(:'digital_certificate_map_list') if (value = attributes[:'digital_certificate_map_list']).is_a?(Array) self.digital_certificate_map_list = value end end if attributes.key?(:'hypervisor_hostname') self.hypervisor_hostname = attributes[:'hypervisor_hostname'] end if attributes.key?(:'model') self.model = attributes[:'model'] end end |
Instance Attribute Details
#block_id ⇒ Object
Rackable unit Id in which node resides.
23 24 25 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 23 def block_id @block_id end |
#digital_certificate_map_list ⇒ Object
List of objects containing digital_certificate_base64 and key_management_server_uuid fields for key management server.
33 34 35 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 33 def digital_certificate_map_list @digital_certificate_map_list end |
#hypervisor_hostname ⇒ Object
Name of the host.
36 37 38 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 36 def hypervisor_hostname @hypervisor_hostname end |
#hypervisor_ip ⇒ Object
Returns the value of attribute hypervisor_ip.
28 29 30 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 28 def hypervisor_ip @hypervisor_ip end |
#ipmi_ip ⇒ Object
Returns the value of attribute ipmi_ip.
30 31 32 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 30 def ipmi_ip @ipmi_ip end |
#model ⇒ Object
Rackable unit model type.
39 40 41 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 39 def model @model end |
#node_position ⇒ Object
Position of a node in a rackable unit.
26 27 28 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 26 def node_position @node_position end |
#node_uuid ⇒ Object
UUID of the host.
20 21 22 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 20 def node_uuid @node_uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 42 def self.attribute_map { :'node_uuid' => :'nodeUuid', :'block_id' => :'blockId', :'node_position' => :'nodePosition', :'hypervisor_ip' => :'hypervisorIp', :'ipmi_ip' => :'ipmiIp', :'digital_certificate_map_list' => :'digitalCertificateMapList', :'hypervisor_hostname' => :'hypervisorHostname', :'model' => :'model' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 249 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 66 def self.openapi_types { :'node_uuid' => :'String', :'block_id' => :'String', :'node_position' => :'String', :'hypervisor_ip' => :'CommonV10ConfigIPAddress', :'ipmi_ip' => :'CommonV10ConfigIPAddress', :'digital_certificate_map_list' => :'Array<ClustermgmtV40ConfigDigitalCertificateMapReference>', :'hypervisor_hostname' => :'String', :'model' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && node_uuid == o.node_uuid && block_id == o.block_id && node_position == o.node_position && hypervisor_ip == o.hypervisor_ip && ipmi_ip == o.ipmi_ip && digital_certificate_map_list == o.digital_certificate_map_list && hypervisor_hostname == o.hypervisor_hostname && model == o.model end |
#eql?(o) ⇒ Boolean
236 237 238 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 236 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 242 def hash [node_uuid, block_id, node_position, hypervisor_ip, ipmi_ip, digital_certificate_map_list, hypervisor_hostname, model].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@node_uuid.nil? && @node_uuid !~ pattern invalid_properties.push("invalid value for \"node_uuid\", must conform to the pattern #{pattern}.") end if !@digital_certificate_map_list.nil? && @digital_certificate_map_list.length > 1024 invalid_properties.push('invalid value for "digital_certificate_map_list", number of items must be less than or equal to 1024.') end if !@digital_certificate_map_list.nil? && @digital_certificate_map_list.length < 0 invalid_properties.push('invalid value for "digital_certificate_map_list", number of items must be greater than or equal to 0.') end if !@hypervisor_hostname.nil? && @hypervisor_hostname.to_s.length > 64 invalid_properties.push('invalid value for "hypervisor_hostname", the character length must be smaller than or equal to 64.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 169 170 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_compute_node_item.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@node_uuid.nil? && @node_uuid !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@digital_certificate_map_list.nil? && @digital_certificate_map_list.length > 1024 return false if !@digital_certificate_map_list.nil? && @digital_certificate_map_list.length < 0 return false if !@hypervisor_hostname.nil? && @hypervisor_hostname.to_s.length > 64 true end |