Class: NutanixClustermgmt::ClustermgmtV40ConfigControllerVmReference

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb

Overview

Host entity with its attributes.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigControllerVmReference

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigControllerVmReference` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigControllerVmReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'external_address')
    self.external_address = attributes[:'external_address']
  end

  if attributes.key?(:'backplane_address')
    self.backplane_address = attributes[:'backplane_address']
  end

  if attributes.key?(:'rdma_backplane_address')
    if (value = attributes[:'rdma_backplane_address']).is_a?(Array)
      self.rdma_backplane_address = value
    end
  end

  if attributes.key?(:'nat_ip')
    self.nat_ip = attributes[:'nat_ip']
  end

  if attributes.key?(:'nat_port')
    self.nat_port = attributes[:'nat_port']
  end

  if attributes.key?(:'is_in_maintenance_mode')
    self.is_in_maintenance_mode = attributes[:'is_in_maintenance_mode']
  end
end

Instance Attribute Details

#backplane_addressObject

Returns the value of attribute backplane_address.



21
22
23
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 21

def backplane_address
  @backplane_address
end

#external_addressObject

Returns the value of attribute external_address.



19
20
21
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 19

def external_address
  @external_address
end

#is_in_maintenance_modeObject

Maintenance mode status.



32
33
34
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 32

def is_in_maintenance_mode
  @is_in_maintenance_mode
end

#nat_ipObject

Returns the value of attribute nat_ip.



26
27
28
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 26

def nat_ip
  @nat_ip
end

#nat_portObject

NAT port.



29
30
31
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 29

def nat_port
  @nat_port
end

#rdma_backplane_addressObject

RDMA backplane address.



24
25
26
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 24

def rdma_backplane_address
  @rdma_backplane_address
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 35

def self.attribute_map
  {
    :'external_address' => :'externalAddress',
    :'backplane_address' => :'backplaneAddress',
    :'rdma_backplane_address' => :'rdmaBackplaneAddress',
    :'nat_ip' => :'natIp',
    :'nat_port' => :'natPort',
    :'is_in_maintenance_mode' => :'isInMaintenanceMode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 57

def self.openapi_types
  {
    :'external_address' => :'CommonV10ConfigIPAddress',
    :'backplane_address' => :'CommonV10ConfigIPAddress',
    :'rdma_backplane_address' => :'Array<CommonV10ConfigIPAddress>',
    :'nat_ip' => :'CommonV10ConfigIPAddress',
    :'nat_port' => :'Integer',
    :'is_in_maintenance_mode' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      external_address == o.external_address &&
      backplane_address == o.backplane_address &&
      rdma_backplane_address == o.rdma_backplane_address &&
      nat_ip == o.nat_ip &&
      nat_port == o.nat_port &&
      is_in_maintenance_mode == o.is_in_maintenance_mode
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 181

def hash
  [external_address, backplane_address, rdma_backplane_address, nat_ip, nat_port, is_in_maintenance_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@rdma_backplane_address.nil? && @rdma_backplane_address.length > 1024
    invalid_properties.push('invalid value for "rdma_backplane_address", number of items must be less than or equal to 1024.')
  end

  if !@rdma_backplane_address.nil? && @rdma_backplane_address.length < 0
    invalid_properties.push('invalid value for "rdma_backplane_address", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_controller_vm_reference.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@rdma_backplane_address.nil? && @rdma_backplane_address.length > 1024
  return false if !@rdma_backplane_address.nil? && @rdma_backplane_address.length < 0
  true
end