Class: NutanixClustermgmt::ClustermgmtV40ConfigDiskReference

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb

Overview

Disk details attached to a host.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigDiskReference

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigDiskReference` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigDiskReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end

  if attributes.key?(:'mount_path')
    self.mount_path = attributes[:'mount_path']
  end

  if attributes.key?(:'size_in_bytes')
    self.size_in_bytes = attributes[:'size_in_bytes']
  end

  if attributes.key?(:'serial_id')
    self.serial_id = attributes[:'serial_id']
  end

  if attributes.key?(:'storage_tier')
    self.storage_tier = attributes[:'storage_tier']
  end
end

Instance Attribute Details

#mount_pathObject

Disk mount path.



23
24
25
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 23

def mount_path
  @mount_path
end

#serial_idObject

Disk serial Id.



29
30
31
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 29

def serial_id
  @serial_id
end

#size_in_bytesObject

Disk size.



26
27
28
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 26

def size_in_bytes
  @size_in_bytes
end

#storage_tierObject

Returns the value of attribute storage_tier.



31
32
33
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 31

def storage_tier
  @storage_tier
end

#uuidObject

Disk UUID.



20
21
22
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 20

def uuid
  @uuid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 56

def self.attribute_map
  {
    :'uuid' => :'uuid',
    :'mount_path' => :'mountPath',
    :'size_in_bytes' => :'sizeInBytes',
    :'serial_id' => :'serialId',
    :'storage_tier' => :'storageTier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 77

def self.openapi_types
  {
    :'uuid' => :'String',
    :'mount_path' => :'String',
    :'size_in_bytes' => :'Integer',
    :'serial_id' => :'String',
    :'storage_tier' => :'ClustermgmtV40ConfigStorageTierReference'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
175
176
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      uuid == o.uuid &&
      mount_path == o.mount_path &&
      size_in_bytes == o.size_in_bytes &&
      serial_id == o.serial_id &&
      storage_tier == o.storage_tier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 186

def hash
  [uuid, mount_path, size_in_bytes, serial_id, storage_tier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
141
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@uuid.nil? && @uuid !~ pattern
    invalid_properties.push("invalid value for \"uuid\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_disk_reference.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@uuid.nil? && @uuid !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  true
end