Class: NutanixClustermgmt::ClustermgmtV40ConfigHttpProxyConfig

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb

Overview

HTTP Proxy server configuration needed to access a cluster which is hosted behind a HTTP Proxy to not reveal its identity.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigHttpProxyConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigHttpProxyConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigHttpProxyConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'proxy_types')
    if (value = attributes[:'proxy_types']).is_a?(Array)
      self.proxy_types = value
    end
  end
end

Instance Attribute Details

#ip_addressObject

Returns the value of attribute ip_address.



19
20
21
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 19

def ip_address
  @ip_address
end

#nameObject

HTTP Proxy server name configuration needed to access a cluster which is hosted behind a HTTP Proxy to not reveal its identity.



31
32
33
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 31

def name
  @name
end

#passwordObject

HTTP Proxy server password needed to access a cluster which is hosted behind a HTTP Proxy to not reveal its identity.



28
29
30
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 28

def password
  @password
end

#portObject

HTTP Proxy server port configuration needed to access a cluster which is hosted behind a HTTP Proxy to not reveal its identity.



22
23
24
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 22

def port
  @port
end

#proxy_typesObject

List of HTTP proxy types.



34
35
36
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 34

def proxy_types
  @proxy_types
end

#usernameObject

HTTP Proxy server username needed to access a cluster which is hosted behind a HTTP Proxy to not reveal its identity.



25
26
27
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 25

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 37

def self.attribute_map
  {
    :'ip_address' => :'ipAddress',
    :'port' => :'port',
    :'username' => :'username',
    :'password' => :'password',
    :'name' => :'name',
    :'proxy_types' => :'proxyTypes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 235

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 59

def self.openapi_types
  {
    :'ip_address' => :'CommonV10ConfigIPAddress',
    :'port' => :'Integer',
    :'username' => :'String',
    :'password' => :'String',
    :'name' => :'String',
    :'proxy_types' => :'Array<ClustermgmtV40ConfigHttpProxyType>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
218
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ip_address == o.ip_address &&
      port == o.port &&
      username == o.username &&
      password == o.password &&
      name == o.name &&
      proxy_types == o.proxy_types
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 222

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



228
229
230
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 228

def hash
  [ip_address, port, username, password, name, proxy_types].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 123

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@username.nil? && @username.to_s.length > 64
    invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 64.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 64
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 64.')
  end

  if !@proxy_types.nil? && @proxy_types.length > 3
    invalid_properties.push('invalid value for "proxy_types", number of items must be less than or equal to 3.')
  end

  if !@proxy_types.nil? && @proxy_types.length < 0
    invalid_properties.push('invalid value for "proxy_types", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



151
152
153
154
155
156
157
158
159
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_http_proxy_config.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@username.nil? && @username.to_s.length > 64
  return false if @name.nil?
  return false if @name.to_s.length > 64
  return false if !@proxy_types.nil? && @proxy_types.length > 3
  return false if !@proxy_types.nil? && @proxy_types.length < 0
  true
end