Class: NutanixClustermgmt::ClustermgmtV40ConfigManagementServerRef

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb

Overview

Management server information.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigManagementServerRef

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigManagementServerRef` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigManagementServerRef`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ip')
    self.ip = attributes[:'ip']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'is_drs_enabled')
    self.is_drs_enabled = attributes[:'is_drs_enabled']
  end

  if attributes.key?(:'is_registered')
    self.is_registered = attributes[:'is_registered']
  end

  if attributes.key?(:'is_in_use')
    self.is_in_use = attributes[:'is_in_use']
  end
end

Instance Attribute Details

#ipObject

Returns the value of attribute ip.



19
20
21
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 19

def ip
  @ip
end

#is_drs_enabledObject

Indicates whether it is DRS enabled or not.



24
25
26
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 24

def is_drs_enabled
  @is_drs_enabled
end

#is_in_useObject

Indicates whether the host is managed by an entity or not.



30
31
32
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 30

def is_in_use
  @is_in_use
end

#is_registeredObject

Indicates whether it is registered or not.



27
28
29
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 27

def is_registered
  @is_registered
end

#typeObject

Returns the value of attribute type.



21
22
23
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 21

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 55

def self.attribute_map
  {
    :'ip' => :'ip',
    :'type' => :'type',
    :'is_drs_enabled' => :'isDrsEnabled',
    :'is_registered' => :'isRegistered',
    :'is_in_use' => :'isInUse'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 76

def self.openapi_types
  {
    :'ip' => :'CommonV10ConfigIPAddress',
    :'type' => :'ClustermgmtV40ConfigManagementServerType',
    :'is_drs_enabled' => :'Boolean',
    :'is_registered' => :'Boolean',
    :'is_in_use' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ip == o.ip &&
      type == o.type &&
      is_drs_enabled == o.is_drs_enabled &&
      is_registered == o.is_registered &&
      is_in_use == o.is_in_use
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 164

def hash
  [ip, type, is_drs_enabled, is_registered, is_in_use].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_management_server_ref.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end