Class: NutanixClustermgmt::ClustermgmtV40ConfigNodeListItemReference
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixClustermgmt::ClustermgmtV40ConfigNodeListItemReference
- Defined in:
- lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb
Overview
List of nodes in a cluster.
Instance Attribute Summary collapse
-
#controller_vm_ip ⇒ Object
Returns the value of attribute controller_vm_ip.
-
#host_ip ⇒ Object
Returns the value of attribute host_ip.
-
#node_uuid ⇒ Object
UUID of the host.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigNodeListItemReference
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigNodeListItemReference
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigNodeListItemReference` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigNodeListItemReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'controller_vm_ip') self.controller_vm_ip = attributes[:'controller_vm_ip'] end if attributes.key?(:'node_uuid') self.node_uuid = attributes[:'node_uuid'] end if attributes.key?(:'host_ip') self.host_ip = attributes[:'host_ip'] end end |
Instance Attribute Details
#controller_vm_ip ⇒ Object
Returns the value of attribute controller_vm_ip.
19 20 21 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 19 def controller_vm_ip @controller_vm_ip end |
#host_ip ⇒ Object
Returns the value of attribute host_ip.
24 25 26 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 24 def host_ip @host_ip end |
#node_uuid ⇒ Object
UUID of the host.
22 23 24 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 22 def node_uuid @node_uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 27 def self.attribute_map { :'controller_vm_ip' => :'controllerVmIp', :'node_uuid' => :'nodeUuid', :'host_ip' => :'hostIp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 150 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 46 def self.openapi_types { :'controller_vm_ip' => :'CommonV10ConfigIPAddress', :'node_uuid' => :'String', :'host_ip' => :'CommonV10ConfigIPAddress' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 127 def ==(o) return true if self.equal?(o) self.class == o.class && controller_vm_ip == o.controller_vm_ip && node_uuid == o.node_uuid && host_ip == o.host_ip end |
#eql?(o) ⇒ Boolean
137 138 139 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 137 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 143 def hash [controller_vm_ip, node_uuid, host_ip].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
91 92 93 94 95 96 97 98 99 100 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 91 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@node_uuid.nil? && @node_uuid !~ pattern invalid_properties.push("invalid value for \"node_uuid\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
104 105 106 107 108 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_list_item_reference.rb', line 104 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@node_uuid.nil? && @node_uuid !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) true end |