Class: NutanixClustermgmt::ClustermgmtV40ConfigNodeNetworkingDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixClustermgmt::ClustermgmtV40ConfigNodeNetworkingDetails
- Defined in:
- lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb
Overview
Network details of nodes.
Instance Attribute Summary collapse
-
#network_info ⇒ Object
Returns the value of attribute network_info.
-
#uplinks ⇒ Object
List of uplinks information for each CVM IP.
-
#warnings ⇒ Object
List of warning messages.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigNodeNetworkingDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigNodeNetworkingDetails
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigNodeNetworkingDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigNodeNetworkingDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'network_info') self.network_info = attributes[:'network_info'] end if attributes.key?(:'uplinks') if (value = attributes[:'uplinks']).is_a?(Array) self.uplinks = value end end if attributes.key?(:'warnings') if (value = attributes[:'warnings']).is_a?(Array) self.warnings = value end end end |
Instance Attribute Details
#network_info ⇒ Object
Returns the value of attribute network_info.
19 20 21 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 19 def network_info @network_info end |
#uplinks ⇒ Object
List of uplinks information for each CVM IP.
22 23 24 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 22 def uplinks @uplinks end |
#warnings ⇒ Object
List of warning messages.
25 26 27 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 25 def warnings @warnings end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 28 def self.attribute_map { :'network_info' => :'networkInfo', :'uplinks' => :'uplinks', :'warnings' => :'warnings' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 47 def self.openapi_types { :'network_info' => :'ClustermgmtV40ConfigNetworkInfo', :'uplinks' => :'Array<ClustermgmtV40ConfigUplinkInfo>', :'warnings' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 167 def ==(o) return true if self.equal?(o) self.class == o.class && network_info == o.network_info && uplinks == o.uplinks && warnings == o.warnings end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 183 def hash [network_info, uplinks, warnings].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 96 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@uplinks.nil? && @uplinks.length > 1024 invalid_properties.push('invalid value for "uplinks", number of items must be less than or equal to 1024.') end if !@uplinks.nil? && @uplinks.length < 0 invalid_properties.push('invalid value for "uplinks", number of items must be greater than or equal to 0.') end if !@warnings.nil? && @warnings.length > 1024 invalid_properties.push('invalid value for "warnings", number of items must be less than or equal to 1024.') end if !@warnings.nil? && @warnings.length < 0 invalid_properties.push('invalid value for "warnings", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 124 125 126 127 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_networking_details.rb', line 120 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@uplinks.nil? && @uplinks.length > 1024 return false if !@uplinks.nil? && @uplinks.length < 0 return false if !@warnings.nil? && @warnings.length > 1024 return false if !@warnings.nil? && @warnings.length < 0 true end |