Class: NutanixClustermgmt::ClustermgmtV40ConfigNodeParam

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb

Overview

Parameters of the node to be added.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigNodeParam

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigNodeParam` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigNodeParam`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'block_list')
    if (value = attributes[:'block_list']).is_a?(Array)
      self.block_list = value
    end
  end

  if attributes.key?(:'node_list')
    if (value = attributes[:'node_list']).is_a?(Array)
      self.node_list = value
    end
  end

  if attributes.key?(:'compute_node_list')
    if (value = attributes[:'compute_node_list']).is_a?(Array)
      self.compute_node_list = value
    end
  end

  if attributes.key?(:'hypervisor_isos')
    if (value = attributes[:'hypervisor_isos']).is_a?(Array)
      self.hypervisor_isos = value
    end
  end

  if attributes.key?(:'hyperv_sku')
    self.hyperv_sku = attributes[:'hyperv_sku']
  end

  if attributes.key?(:'bundle_info')
    self.bundle_info = attributes[:'bundle_info']
  end

  if attributes.key?(:'should_skip_host_networking')
    self.should_skip_host_networking = attributes[:'should_skip_host_networking']
  end
end

Instance Attribute Details

#block_listObject

Block list of a cluster.



20
21
22
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 20

def block_list
  @block_list
end

#bundle_infoObject

Returns the value of attribute bundle_info.



34
35
36
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 34

def bundle_info
  @bundle_info
end

#compute_node_listObject

List of compute only nodes.



26
27
28
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 26

def compute_node_list
  @compute_node_list
end

#hyperv_skuObject

Hyperv SKU.



32
33
34
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 32

def hyperv_sku
  @hyperv_sku
end

#hypervisor_isosObject

Hypervisor type to md5sum map.



29
30
31
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 29

def hypervisor_isos
  @hypervisor_isos
end

#node_listObject

List of nodes in a cluster.



23
24
25
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 23

def node_list
  @node_list
end

#should_skip_host_networkingObject

Indicates if the host networking needs to be skipped or not.



37
38
39
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 37

def should_skip_host_networking
  @should_skip_host_networking
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 40

def self.attribute_map
  {
    :'block_list' => :'blockList',
    :'node_list' => :'nodeList',
    :'compute_node_list' => :'computeNodeList',
    :'hypervisor_isos' => :'hypervisorIsos',
    :'hyperv_sku' => :'hypervSku',
    :'bundle_info' => :'bundleInfo',
    :'should_skip_host_networking' => :'shouldSkipHostNetworking'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 290

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 63

def self.openapi_types
  {
    :'block_list' => :'Array<ClustermgmtV40ConfigBlockItem>',
    :'node_list' => :'Array<ClustermgmtV40ConfigNodeItem>',
    :'compute_node_list' => :'Array<ClustermgmtV40ConfigComputeNodeItem>',
    :'hypervisor_isos' => :'Array<ClustermgmtV40ConfigHypervisorIsoMap>',
    :'hyperv_sku' => :'String',
    :'bundle_info' => :'ClustermgmtV40ConfigBundleInfo',
    :'should_skip_host_networking' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



263
264
265
266
267
268
269
270
271
272
273
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 263

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      block_list == o.block_list &&
      node_list == o.node_list &&
      compute_node_list == o.compute_node_list &&
      hypervisor_isos == o.hypervisor_isos &&
      hyperv_sku == o.hyperv_sku &&
      bundle_info == o.bundle_info &&
      should_skip_host_networking == o.should_skip_host_networking
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


277
278
279
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 277

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



283
284
285
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 283

def hash
  [block_list, node_list, compute_node_list, hypervisor_isos, hyperv_sku, bundle_info, should_skip_host_networking].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@block_list.nil? && @block_list.length > 1024
    invalid_properties.push('invalid value for "block_list", number of items must be less than or equal to 1024.')
  end

  if !@block_list.nil? && @block_list.length < 0
    invalid_properties.push('invalid value for "block_list", number of items must be greater than or equal to 0.')
  end

  if !@node_list.nil? && @node_list.length > 1024
    invalid_properties.push('invalid value for "node_list", number of items must be less than or equal to 1024.')
  end

  if !@node_list.nil? && @node_list.length < 0
    invalid_properties.push('invalid value for "node_list", number of items must be greater than or equal to 0.')
  end

  if !@compute_node_list.nil? && @compute_node_list.length > 1024
    invalid_properties.push('invalid value for "compute_node_list", number of items must be less than or equal to 1024.')
  end

  if !@compute_node_list.nil? && @compute_node_list.length < 0
    invalid_properties.push('invalid value for "compute_node_list", number of items must be greater than or equal to 0.')
  end

  if !@hypervisor_isos.nil? && @hypervisor_isos.length > 1024
    invalid_properties.push('invalid value for "hypervisor_isos", number of items must be less than or equal to 1024.')
  end

  if !@hypervisor_isos.nil? && @hypervisor_isos.length < 0
    invalid_properties.push('invalid value for "hypervisor_isos", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 312

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_param.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@block_list.nil? && @block_list.length > 1024
  return false if !@block_list.nil? && @block_list.length < 0
  return false if !@node_list.nil? && @node_list.length > 1024
  return false if !@node_list.nil? && @node_list.length < 0
  return false if !@compute_node_list.nil? && @compute_node_list.length > 1024
  return false if !@compute_node_list.nil? && @compute_node_list.length < 0
  return false if !@hypervisor_isos.nil? && @hypervisor_isos.length > 1024
  return false if !@hypervisor_isos.nil? && @hypervisor_isos.length < 0
  true
end