Class: NutanixClustermgmt::ClustermgmtV40ConfigNodeResourceConfig
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixClustermgmt::ClustermgmtV40ConfigNodeResourceConfig
- Defined in:
- lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb
Overview
Node resource configuration.
Instance Attribute Summary collapse
-
#container_ext_id ⇒ Object
ExtId for the container on which Node storage has to be hosted on.
-
#data_disk_size_bytes ⇒ Object
Data disk size for a given node in cluster.
-
#memory_size_bytes ⇒ Object
Memory for a given node in cluster.
-
#num_vcpus ⇒ Object
Number of Vcpus for a given node in cluster.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigNodeResourceConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigNodeResourceConfig
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigNodeResourceConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigNodeResourceConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'num_vcpus') self.num_vcpus = attributes[:'num_vcpus'] end if attributes.key?(:'memory_size_bytes') self.memory_size_bytes = attributes[:'memory_size_bytes'] end if attributes.key?(:'data_disk_size_bytes') self.data_disk_size_bytes = attributes[:'data_disk_size_bytes'] end if attributes.key?(:'container_ext_id') self.container_ext_id = attributes[:'container_ext_id'] end end |
Instance Attribute Details
#container_ext_id ⇒ Object
ExtId for the container on which Node storage has to be hosted on.
29 30 31 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 29 def container_ext_id @container_ext_id end |
#data_disk_size_bytes ⇒ Object
Data disk size for a given node in cluster.
26 27 28 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 26 def data_disk_size_bytes @data_disk_size_bytes end |
#memory_size_bytes ⇒ Object
Memory for a given node in cluster.
23 24 25 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 23 def memory_size_bytes @memory_size_bytes end |
#num_vcpus ⇒ Object
Number of Vcpus for a given node in cluster.
20 21 22 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 20 def num_vcpus @num_vcpus end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 32 def self.attribute_map { :'num_vcpus' => :'numVcpus', :'memory_size_bytes' => :'memorySizeBytes', :'data_disk_size_bytes' => :'dataDiskSizeBytes', :'container_ext_id' => :'containerExtId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 162 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 52 def self.openapi_types { :'num_vcpus' => :'Integer', :'memory_size_bytes' => :'Integer', :'data_disk_size_bytes' => :'Integer', :'container_ext_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && num_vcpus == o.num_vcpus && memory_size_bytes == o.memory_size_bytes && data_disk_size_bytes == o.data_disk_size_bytes && container_ext_id == o.container_ext_id end |
#eql?(o) ⇒ Boolean
149 150 151 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 149 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 155 def hash [num_vcpus, memory_size_bytes, data_disk_size_bytes, container_ext_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
102 103 104 105 106 107 108 109 110 111 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 102 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@container_ext_id.nil? && @container_ext_id !~ pattern invalid_properties.push("invalid value for \"container_ext_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 184 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
115 116 117 118 119 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_node_resource_config.rb', line 115 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@container_ext_id.nil? && @container_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) true end |