Class: NutanixClustermgmt::ClustermgmtV40ConfigRackableUnitNode
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixClustermgmt::ClustermgmtV40ConfigRackableUnitNode
- Defined in:
- lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb
Overview
Node information registered to this rackable unit.
Instance Attribute Summary collapse
-
#position ⇒ Object
Position of a node in a rackable unit.
-
#svm_id ⇒ Object
Controller VM Id.
-
#uuid ⇒ Object
UUID of the host.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigRackableUnitNode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigRackableUnitNode
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigRackableUnitNode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigRackableUnitNode`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'svm_id') self.svm_id = attributes[:'svm_id'] end if attributes.key?(:'position') self.position = attributes[:'position'] end end |
Instance Attribute Details
#position ⇒ Object
Position of a node in a rackable unit.
26 27 28 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 26 def position @position end |
#svm_id ⇒ Object
Controller VM Id.
23 24 25 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 23 def svm_id @svm_id end |
#uuid ⇒ Object
UUID of the host.
20 21 22 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 20 def uuid @uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 29 def self.attribute_map { :'uuid' => :'uuid', :'svm_id' => :'svmId', :'position' => :'position' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 152 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 48 def self.openapi_types { :'uuid' => :'String', :'svm_id' => :'Integer', :'position' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 129 def ==(o) return true if self.equal?(o) self.class == o.class && uuid == o.uuid && svm_id == o.svm_id && position == o.position end |
#eql?(o) ⇒ Boolean
139 140 141 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 139 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
145 146 147 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 145 def hash [uuid, svm_id, position].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 102 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@uuid.nil? && @uuid !~ pattern invalid_properties.push("invalid value for \"uuid\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 110 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_rackable_unit_node.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@uuid.nil? && @uuid !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) true end |