Class: NutanixClustermgmt::ClustermgmtV40ConfigDataStore
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixClustermgmt::ClustermgmtV40ConfigDataStore
- Defined in:
- lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb
Instance Attribute Summary collapse
-
#capacity_bytes ⇒ Object
Maximum physical capacity of the Storage Container in bytes.
-
#container_ext_id ⇒ Object
The external identifier of the Storage Container.
-
#container_name ⇒ Object
Name of the Storage Container.
-
#datastore_name ⇒ Object
Name of the datastore.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#free_space_bytes ⇒ Object
The free space in the datastore.
-
#host_ext_id ⇒ Object
The external identifier of the host for the datastore.
-
#host_ip_address ⇒ Object
Host IP for datastore.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
-
#vm_names ⇒ Object
List of VM names in the datastore.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigDataStore
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigDataStore
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigDataStore` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigDataStore`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'datastore_name') self.datastore_name = attributes[:'datastore_name'] end if attributes.key?(:'container_ext_id') self.container_ext_id = attributes[:'container_ext_id'] end if attributes.key?(:'container_name') self.container_name = attributes[:'container_name'] end if attributes.key?(:'host_ext_id') self.host_ext_id = attributes[:'host_ext_id'] end if attributes.key?(:'host_ip_address') self.host_ip_address = attributes[:'host_ip_address'] end if attributes.key?(:'capacity_bytes') self.capacity_bytes = attributes[:'capacity_bytes'] end if attributes.key?(:'free_space_bytes') self.free_space_bytes = attributes[:'free_space_bytes'] end if attributes.key?(:'vm_names') if (value = attributes[:'vm_names']).is_a?(Array) self.vm_names = value end end end |
Instance Attribute Details
#capacity_bytes ⇒ Object
Maximum physical capacity of the Storage Container in bytes.
43 44 45 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 43 def capacity_bytes @capacity_bytes end |
#container_ext_id ⇒ Object
The external identifier of the Storage Container.
31 32 33 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 31 def container_ext_id @container_ext_id end |
#container_name ⇒ Object
Name of the Storage Container. Note that the name of Storage Container should be unique in every cluster.
34 35 36 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 34 def container_name @container_name end |
#datastore_name ⇒ Object
Name of the datastore.
28 29 30 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 28 def datastore_name @datastore_name end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
22 23 24 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 22 def ext_id @ext_id end |
#free_space_bytes ⇒ Object
The free space in the datastore.
46 47 48 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 46 def free_space_bytes @free_space_bytes end |
#host_ext_id ⇒ Object
The external identifier of the host for the datastore.
37 38 39 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 37 def host_ext_id @host_ext_id end |
#host_ip_address ⇒ Object
Host IP for datastore.
40 41 42 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 40 def host_ip_address @host_ip_address end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
25 26 27 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 25 def links @links end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
19 20 21 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 19 def tenant_id @tenant_id end |
#vm_names ⇒ Object
List of VM names in the datastore.
49 50 51 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 49 def vm_names @vm_names end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 52 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'datastore_name' => :'datastoreName', :'container_ext_id' => :'containerExtId', :'container_name' => :'containerName', :'host_ext_id' => :'hostExtId', :'host_ip_address' => :'hostIpAddress', :'capacity_bytes' => :'capacityBytes', :'free_space_bytes' => :'freeSpaceBytes', :'vm_names' => :'vmNames' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 417 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
103 104 105 106 107 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 103 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 100 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 96 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 79 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'datastore_name' => :'String', :'container_ext_id' => :'String', :'container_name' => :'String', :'host_ext_id' => :'String', :'host_ip_address' => :'String', :'capacity_bytes' => :'Integer', :'free_space_bytes' => :'Integer', :'vm_names' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 386 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && datastore_name == o.datastore_name && container_ext_id == o.container_ext_id && container_name == o.container_name && host_ext_id == o.host_ext_id && host_ip_address == o.host_ip_address && capacity_bytes == o.capacity_bytes && free_space_bytes == o.free_space_bytes && vm_names == o.vm_names end |
#eql?(o) ⇒ Boolean
404 405 406 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 404 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
410 411 412 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 410 def hash [tenant_id, ext_id, links, datastore_name, container_ext_id, container_name, host_ext_id, host_ip_address, capacity_bytes, free_space_bytes, vm_names].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 176 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if !@datastore_name.nil? && @datastore_name.to_s.length > 255 invalid_properties.push('invalid value for "datastore_name", the character length must be smaller than or equal to 255.') end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@container_ext_id.nil? && @container_ext_id !~ pattern invalid_properties.push("invalid value for \"container_ext_id\", must conform to the pattern #{pattern}.") end if !@container_name.nil? && @container_name.to_s.length > 75 invalid_properties.push('invalid value for "container_name", the character length must be smaller than or equal to 75.') end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@host_ext_id.nil? && @host_ext_id !~ pattern invalid_properties.push("invalid value for \"host_ext_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/#\/components\/schemas\/common.v1.r0.config.IPAddressOrFQDN/) if !@host_ip_address.nil? && @host_ip_address !~ pattern invalid_properties.push("invalid value for \"host_ip_address\", must conform to the pattern #{pattern}.") end if !@vm_names.nil? && @vm_names.length > 5000 invalid_properties.push('invalid value for "vm_names", number of items must be less than or equal to 5000.') end if !@vm_names.nil? && @vm_names.length < 0 invalid_properties.push('invalid value for "vm_names", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 439 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store.rb', line 233 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@datastore_name.nil? && @datastore_name.to_s.length > 255 return false if !@container_ext_id.nil? && @container_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@container_name.nil? && @container_name.to_s.length > 75 return false if !@host_ext_id.nil? && @host_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@host_ip_address.nil? && @host_ip_address !~ Regexp.new(/#\/components\/schemas\/common.v1.r0.config.IPAddressOrFQDN/) return false if !@vm_names.nil? && @vm_names.length > 5000 return false if !@vm_names.nil? && @vm_names.length < 0 true end |