Class: NutanixClustermgmt::ClustermgmtV40ConfigDataStoreMount
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixClustermgmt::ClustermgmtV40ConfigDataStoreMount
- Defined in:
- lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb
Instance Attribute Summary collapse
-
#container_name ⇒ Object
Name of the Storage Container.
-
#datastore_name ⇒ Object
Name of the datastore.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#is_read_only ⇒ Object
Indicates weather the host system has read-only access to the NFS share.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#node_ext_ids ⇒ Object
The UUIDs of the nodes where the NFS datastore has to be created.
-
#target_path ⇒ Object
The target path on which to mount the NFS datastore.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigDataStoreMount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClustermgmtV40ConfigDataStoreMount
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixClustermgmt::ClustermgmtV40ConfigDataStoreMount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixClustermgmt::ClustermgmtV40ConfigDataStoreMount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'datastore_name') self.datastore_name = attributes[:'datastore_name'] end if attributes.key?(:'container_name') self.container_name = attributes[:'container_name'] else self.container_name = nil end if attributes.key?(:'node_ext_ids') if (value = attributes[:'node_ext_ids']).is_a?(Array) self.node_ext_ids = value end end if attributes.key?(:'is_read_only') self.is_read_only = attributes[:'is_read_only'] end if attributes.key?(:'target_path') self.target_path = attributes[:'target_path'] end end |
Instance Attribute Details
#container_name ⇒ Object
Name of the Storage Container. Note that the name of Storage Container should be unique in every cluster.
31 32 33 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 31 def container_name @container_name end |
#datastore_name ⇒ Object
Name of the datastore.
28 29 30 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 28 def datastore_name @datastore_name end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
22 23 24 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 22 def ext_id @ext_id end |
#is_read_only ⇒ Object
Indicates weather the host system has read-only access to the NFS share.
37 38 39 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 37 def is_read_only @is_read_only end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
25 26 27 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 25 def links @links end |
#node_ext_ids ⇒ Object
The UUIDs of the nodes where the NFS datastore has to be created.
34 35 36 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 34 def node_ext_ids @node_ext_ids end |
#target_path ⇒ Object
The target path on which to mount the NFS datastore.
40 41 42 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 40 def target_path @target_path end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
19 20 21 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 19 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 43 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'datastore_name' => :'datastoreName', :'container_name' => :'containerName', :'node_ext_ids' => :'nodeExtIds', :'is_read_only' => :'isReadOnly', :'target_path' => :'targetPath' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 331 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
88 89 90 91 92 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 88 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 81 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 67 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'datastore_name' => :'String', :'container_name' => :'String', :'node_ext_ids' => :'Array<String>', :'is_read_only' => :'Boolean', :'target_path' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 303 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && datastore_name == o.datastore_name && container_name == o.container_name && node_ext_ids == o.node_ext_ids && is_read_only == o.is_read_only && target_path == o.target_path end |
#eql?(o) ⇒ Boolean
318 319 320 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 318 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
324 325 326 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 324 def hash [tenant_id, ext_id, links, datastore_name, container_name, node_ext_ids, is_read_only, target_path].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if !@datastore_name.nil? && @datastore_name.to_s.length > 255 invalid_properties.push('invalid value for "datastore_name", the character length must be smaller than or equal to 255.') end if @container_name.nil? invalid_properties.push('invalid value for "container_name", container_name cannot be nil.') end if @container_name.to_s.length > 75 invalid_properties.push('invalid value for "container_name", the character length must be smaller than or equal to 75.') end if !@node_ext_ids.nil? && @node_ext_ids.length > 50 invalid_properties.push('invalid value for "node_ext_ids", number of items must be less than or equal to 50.') end if !@node_ext_ids.nil? && @node_ext_ids.length < 0 invalid_properties.push('invalid value for "node_ext_ids", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/nutanix_clustermgmt/models/clustermgmt_v40_config_data_store_mount.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@datastore_name.nil? && @datastore_name.to_s.length > 255 return false if @container_name.nil? return false if @container_name.to_s.length > 75 return false if !@node_ext_ids.nil? && @node_ext_ids.length > 50 return false if !@node_ext_ids.nil? && @node_ext_ids.length < 0 true end |